@@ -30,10 +30,16 @@ from __future__ import unicode_literals
 
 from pyqtgraph import QtCore
 import time
+import logging
+
 from .omniQThread import OmniQThread
 
-#: (:obj:`float`) refresh rate in seconds
-GLOBALREFRESHRATE = .1
+#: (:obj:`float`) refresh time in seconds
+GLOBALREFRESHTIME = .1
+#: (:obj:`bool`) auto enlarge time
+GLOBALAUTOREFRESHTIME = True
+
+logger = logging.getLogger("lavue")
 
 
 class ExchangeList(object):
@@ -81,7 +87,7 @@ class DataFetchThread(OmniQThread):
     #: (:class:`pyqtgraph.QtCore.pyqtSignal`) new data name signal
     newDataNameFetched = QtCore.pyqtSignal(str, str)
 
-    def __init__(self, datasource, alist):
+    def __init__(self, datasource, alist, tid=0):
         """ constructor
 
         :param datasource: image source
@@ -100,27 +106,68 @@ class DataFetchThread(OmniQThread):
         self.__loop = False
         #: (:obj:`bool`) ready flag
         self.__ready = True
+        #: (:obj:`int`) thread id
+        self.__tid = tid
         #: (:class:`pyqtgraph.QtCore.QMutex`) thread mutex
         self.__mutex = QtCore.QMutex()
+        #: (:obj:`int`) current timestamp
+        self.__tm = time.time()
+        #: (:obj:`int`) current timestamp
+        self.__tm2 = time.time()
+        #: (:obj:`int`) current timestamp
+        self.__dt = 0
+        #: (:obj:`int`) counter
+        self.__counter = 0
+        #: (:obj:`int`) maximal counter value
+        self.__maxcounter = 100
+        #: (:obj:`int`) start time
+        self.__starttime = 0
+        #: (:obj:`float`) elapsed time factor
+        self.__factor = 2.0
 
     def _run(self):
         """ run function of the fetching thread
         """
+        global GLOBALREFRESHTIME
         self.__loop = True
-        dt = 0
+        self.__dt = 0
         skip = False
         while self.__loop:
             if not self.__isConnected:
-                self.msleep(int(1000*GLOBALREFRESHRATE))
+                self.msleep(int(1000*GLOBALREFRESHTIME))
             if skip:
-                self.msleep(int(100*GLOBALREFRESHRATE))
+                self.msleep(int(100*GLOBALREFRESHTIME))
             else:
-                self.msleep(max(int(1000*GLOBALREFRESHRATE - dt), 0))
-            t1 = time.time()
+                for _ in range(3):
+                    self.msleep(
+                        max(int((1000*GLOBALREFRESHTIME - self.__dt)/4.), 0))
+            self.msleep(
+                max(int(
+                    1000*GLOBALREFRESHTIME
+                    - (time.time() - self.__tm) * 1000.), 0))
+            self.__tm = time.time()
             if self.__isConnected and self.__ready:
                 try:
                     with QtCore.QMutexLocker(self.__mutex):
                         img, name, metadata = self.__datasource.getData()
+                    if not self.__tid and GLOBALAUTOREFRESHTIME:
+                        if not self.__counter:
+                            self.__starttime = self.__tm
+                        if self.__counter == self.__maxcounter:
+                            etime = time.time()
+                            if self.__starttime:
+                                eltime = float(etime - self.__starttime) \
+                                    / self.__maxcounter
+                                # print(eltime, GLOBALREFRESHTIME)
+                                if eltime > self.__factor * GLOBALREFRESHTIME:
+                                    GLOBALREFRESHTIME = GLOBALREFRESHTIME * \
+                                        self.__factor
+                                    logger.warning(
+                                        "The Image refresh time changed to: "
+                                        "%s s" % GLOBALREFRESHTIME)
+                            self.__counter = 0
+                        else:
+                            self.__counter += 1
                 except Exception as e:
                     name = "__ERROR__"
                     img = str(e)
@@ -128,13 +175,16 @@ class DataFetchThread(OmniQThread):
                 if name is not None:
                     self.__list.addData(name, img, metadata)
                     self.__ready = False
+                    # print(self.__tid, "ADDED", time.time())
                     self.newDataNameFetched.emit(name, metadata)
                 else:
                     self.__ready = True
                 skip = False
             else:
                 skip = True
-            dt = (time.time() - t1) * 1000.
+            self.__tm2 = time.time()
+            self.__dt = (self.__tm2 - self.__tm) * 1000.
+            # print("END", self.__tid, self.__dt)
 
     @QtCore.pyqtSlot(bool)
     def changeStatus(self, status):
@@ -146,6 +196,23 @@ class DataFetchThread(OmniQThread):
         self.__isConnected = status
         self.__ready = True
 
+    def setTimeStamp(self, tmstamp):
+        """ set time stamp
+
+        :param tmstamp: set timestamp
+        :type tmstamp: :obj:`int`
+        """
+        self.__tm = tmstamp
+        self.__dt = (self.__tm2 - self.__tm+0.0010) * 1000.
+
+    def getTimeStamp(self):
+        """ get time stamp
+
+        :returns: time stamp
+        :rtype: :obj:`int`
+        """
+        return self.__tm
+
     def setDataSource(self, datasource):
         """ sets datasource
         :param datasource: datasource object
