@@ -962,6 +962,10 @@ class CutExtension(DisplayExtension):
         self.__timelock = 0
         #: (:obj:`float`) time to lock
         self.__timetolock = 0.5
+        #: (:obj:`bool`) cut on clickcurrent roi drown id
+        self.__cutonclick = True
+        #: (:obj:`bool`) centering flakg
+        self.__centering = True
 
         #: (:obj:`int`) current cut id
         self.__current = 0
@@ -1003,6 +1007,10 @@ class CutExtension(DisplayExtension):
         if parameters.cuts is not None:
             self.__showCuts(parameters.cuts)
             self._enabled = parameters.cuts
+        if parameters.cutonclick is not None:
+            self.__cutonclick = parameters.cutonclick
+        if parameters.centering is not None:
+            self.__centering = parameters.centering
 
     def __addCutCoords(self, coords):
         """ adds Cut coordinates
@@ -1025,7 +1033,10 @@ class CutExtension(DisplayExtension):
                     ln = nozero(d.length())
                     ang = _pg.Point(1, 0).angle(d)
                     crd.setPos(pos1)
-                    crd.setSize([ln, crd.size()[1]])
+                    if len(coords[i]) > 4:
+                        crd.setSize([ln, coords[i][4]])
+                    else:
+                        crd.setSize([ln, crd.size()[1]])
                     crd.setAngle(-ang)
 
     def __addCut(self, coords=None):
@@ -1247,17 +1258,18 @@ class CutExtension(DisplayExtension):
         :type locked: :obj:`bool`
         """
         # print("DOUBLE", x, y, self.__drawing, locked)
-        if self.__drawing < 0 and \
-                (time.time() - self.__timelock) > self.__timetolock:
-            self.__drawing = len(self.__cut)
-            coords = list(self.cutCoords())
-            if not self._mainwidget.transformations()[0]:
-                crd = [x, y, x, y, 0.00001]
-            else:
-                crd = [y, x, y, x, 0.00001]
-            coords.append(crd)
-            self.updateCuts(len(coords), coords)
-            self.__drawpos = [x, y]
+        if self.__cutonclick:
+            if self.__drawing < 0 and \
+                    (time.time() - self.__timelock) > self.__timetolock:
+                self.__drawing = len(self.__cut)
+                coords = list(self.cutCoords())
+                if not self._mainwidget.transformations()[0]:
+                    crd = [x, y, x, y, 0.00001]
+                else:
+                    crd = [y, x, y, x, 0.00001]
+                coords.append(crd)
+                self.updateCuts(len(coords), coords)
+                self.__drawpos = [x, y]
 
     def mouse_click(self, x, y):
         """  sets vLine and hLine positions
@@ -1268,18 +1280,19 @@ class CutExtension(DisplayExtension):
         :type y: :obj:`float`
         """
         # print("SINGLE", x, y, self.__drawing)
-        if self.__drawing >= 0:
-            self.__timelock = time.time()
-            x0, y0 = self.__drawpos
+        if self.__cutonclick:
+            if self.__drawing >= 0:
+                self.__timelock = time.time()
+                x0, y0 = self.__drawpos
 
-            if not self._mainwidget.transformations()[0]:
-                crd = [x0, y0, x, y, 0.00001]
-            else:
-                crd = [y0, x0, y, x, 0.00001]
-            self.__coords[-1] = crd
-            self.__drawing = -1
-            self.updateCuts(len(self.__coords), self.__coords)
-            self.cutNumberChanged.emit(len(self.__coords))
+                if not self._mainwidget.transformations()[0]:
+                    crd = [x0, y0, x, y, 0.00001]
+                else:
+                    crd = [y0, x0, y, x, 0.00001]
+                self.__coords[-1] = crd
+                self.__drawing = -1
+                self.updateCuts(len(self.__coords), self.__coords)
+                self.cutNumberChanged.emit(len(self.__coords))
 
 
 class MeshExtension(DisplayExtension):
@@ -2359,3 +2372,97 @@ class MaximaExtension(DisplayExtension):
         """
         positionlist = [(pos[1], pos[0]) for pos in self.__positions]
         self.setMaximaPos(positionlist)
+
+
+class EllipseExtension(DisplayExtension):
+
+    def __init__(self, parent=None):
+        """ constructor
+
+        :param parent: parent object
+        :type parent: :class:`pyqtgraph.QtCore.QObject`
+        """
+        DisplayExtension.__init__(self, parent)
+
+        #: (:obj:`str`) tool name
+        self.name = "ellipse"
+
+        #: (:obj:`list` < > ) ellipse parameters
+        self.__positions = []
+
+        #: (:obj:`list` < > ) ellipse objects
+        self.__ellipse = []
+
+    def show(self, parameters):
+        """ set subwidget properties
+
+        :param parameters: tool parameters
+        :type parameters: :class:`lavuelib.toolWidget.ToolParameters`
+        """
+        if parameters.ellipse is not None:
+            self.__showEllipse(parameters.ellipse)
+            self._enabled = parameters.ellipse
+
+    def __showEllipse(self, status):
+        """ shows or hides ellipse
+
+        :param status: will be shown
+        :type status: :obj:`bool`
+        """
+        if status:
+            if self.__positions:
+                for el in self.__ellipse:
+                    el.show()
+        else:
+            for el in self.__ellipse:
+                el.hide()
+
+    def setEllipsePos(self, positionlist, offset=None):
+        """
+        sets ellipse positions
+
+        :param positionlist: [(x1, y1), ... , (xn, yn)]
+        :type positionlist: :obj:`list` < (:obj:`float`, :obj:`float`) >
+        :param offset: offset of position
+        :type offset: [ :obj:`float`, :obj:`float`]
+        """
+        if offset is None:
+            offset = [0.5, 0.5]
+        self.__positions = positionlist or []
+        eid = len(self.__positions)
+        # print("POS", self.__positions)
+
+        for ei in range(min(eid, len(self.__ellipse))):
+            coords = self.__positions[ei]
+            self.__ellipse[ei].setPos([coords[0] + offset[0] - coords[2],
+                                       coords[1] + offset[1] - coords[3]])
+            self.__ellipse[ei].setSize([2 * coords[2], 2 * coords[3]])
+            self.__ellipse[ei].setAngle(coords[4])
+            if self._enabled:
+                self.__ellipse[ei].show()
+        while eid > len(self.__ellipse):
+            ie = len(self.__ellipse)
+            coords = self.__positions[ie]
+
+            el = _pg.EllipseROI([coords[0] + offset[0] - coords[2],
+                                 coords[1] + offset[1] - coords[3]],
+                                [2 * coords[2], 2 * coords[3]],
+                                angle=coords[4],
+                                movable=False,
+                                resizable=False,
+                                rotatable=False)
+            if self._enabled:
+                el.show()
+            self._mainwidget.viewbox().addItem(el)
+            while el.handles:
+                el.removeHandle(0)
+            self.__ellipse.append(el)
+        for ei in range(eid, len(self.__ellipse)):
+            self.__ellipse[ei].hide()
+
+    def transpose(self):
+        """ transposes maxima
+        """
+        positionlist = [(pos[1], pos[0], pos[3], pos[2], pos[4])
+                        for pos in self.__positions]
+        self.setEllipsePos(positionlist)
