@@ -32,7 +32,7 @@ import numpy
 import sys
 
 
-#: (:mod:`H5PYWriter`or :mod:`H5CppWriter`)
+#: (:mod:`PNIWriter` or :mod:`H5PYWriter`or :mod:`H5CppWriter`)
 #    default writer module
 writer = None
 
@@ -40,6 +40,13 @@ writer = None
 writerlock = threading.Lock()
 
 
+try:
+    _npver = numpy.version.version.split(".")
+    NPMAJOR = int(_npver[0])
+except Exception:
+    NPMAJOR = 1
+
+
 def open_file(filename, readonly=False, **pars):
     """ open the new file
 
@@ -290,7 +297,7 @@ def setwriter(wr):
     """ sets writer
 
     :param wr: writer module
-    :type wr: :mod:`H5PYWriter` or :mod:`H5CppWriter`
+    :type wr: :mod:`PNIWriter` or :mod:`H5PYWriter` or :mod:`H5CppWriter`
     """
     global writer
     with writerlock:
@@ -304,13 +311,13 @@ class FTHyperslab(object):
         """ constructor
 
         :param offset: a list of offsets
-        :type offset: :obj:`tuple`
+        :type offset: :obj:`tuple` <:obj:`int`>
         :param block: a list of blocks
-        :type block: :obj:`tuple`
+        :type block: :obj:`tuple` <:obj:`int`>
         :param count: a list of counts
-        :type count: :obj:`tuple`
+        :type count: :obj:`tuple` <:obj:`int`>
         :param stride: a list of strides
-        :type stride: :obj:`tuple`
+        :type stride: :obj:`tuple` <:obj:`int`>
         """
         self.offset = offset
         self.block = block
@@ -453,7 +460,14 @@ def first(array):
         if isinstance(array, numpy.ndarray) and len(array) == 1:
             return array[0]
     except Exception:
-        pass
+        try:
+            if hasattr(array, "all"):
+                if NPMAJOR < 2:
+                    array = array.all()
+                if hasattr(array, "decode"):
+                    return array.decode()
+        except Exception:
+            pass
     return array
 
 
@@ -470,12 +484,13 @@ class FTFile(FTObject):
         :param filename:  file name
         :type filename: :obj:`str`
         :param writer: writer module
-        :type writer: :mod:`H5PYWriter` or :mod:`H5CppWriter`
+        :type writer: :mod:`PNIWriter` or :mod:`H5PYWriter`
+                        or :mod:`H5CppWriter`
         """
         FTObject.__init__(self, h5object, None)
         #: (:obj:`str`) file name
         self.name = filename
-        #: (:mod:`H5PYWriter` or :mod:`H5CppWriter`)
+        #: (:mod:`PNIWriter` or :mod:`H5PYWriter` or :mod:`H5CppWriter`)
         # writer module
         self.writer = None
 
@@ -526,6 +541,8 @@ class FTFile(FTObject):
         :rtype: :obj:`str`
         """
         tzone = time.tzname[0]
+        if tzone in ['CET', 'CEST']:
+            tzone = 'Europe/Berlin'
         fmt = '%Y-%m-%dT%H:%M:%S.%f%z'
         try:
             if sys.version_info >= (3, 9):
@@ -548,69 +565,7 @@ class FTFile(FTObject):
         :returns: field pointed by default attributes
         :rtype: :class:`FTField`
         """
-        node = self.root()
-        searching = True
-        while searching:
-            attrs = node.attributes
-            if hasattr(node, "names") and "default" in attrs.names():
-                nname = attrs["default"].read()
-                if isinstance(nname, numpy.ndarray) and len(nname):
-                    nname = nname[0]
-                if nname in node.names():
-                    node = node.open(nname)
-                    continue
-            searching = False
-        if hasattr(node, "names"):
-            attrs = node.attributes
-            if "signal" in attrs.names():
-                nname = attrs["signal"].read()
-                if isinstance(nname, numpy.ndarray) and len(nname):
-                    nname = nname[0]
-                if nname in node.names():
-                    node = node.open(nname)
-        if not hasattr(node, "names"):
-            return node
-
-        for cnm in ["NXentry", "NXdata", "NXmonitor", "NXlog"]:
-            names = node.names()
-            if cnm[2:] in names:
-                snames = [cnm[2:]]
-            else:
-                snames = []
-            snames.extend(sorted([nm for nm in names if nm != cnm[2:]]))
-            for nn in snames:
-                nd = node.open(nn)
-                if not hasattr(nd, "attributes"):
-                    continue
-                attrs = nd.attributes
-                if "NX_class" in attrs.names():
-                    nname = attrs["NX_class"].read()
-                    if isinstance(nname, numpy.ndarray) and len(nname):
-                        nname = nname[0]
-                    if nname in cnm:
-                        node = nd
-                        break
-        if hasattr(node, "names") and hasattr(node, "attributes"):
-            attrs = node.attributes
-            if "signal" in attrs.names():
-                nname = attrs["signal"].read()
-                if isinstance(nname, numpy.ndarray) and len(nname):
-                    nname = nname[0]
-                if nname in node.names():
-                    node = node.open(nname)
-        if not hasattr(node, "names"):
-            return node
-        while hasattr(node, "names") and "data" in node.names():
-            node = node.open("data")
-        if hasattr(node, "names"):
-            for nn in sorted(node.names()):
-                nd = node.open(nn)
-                if not hasattr(nd, "names"):
-                    node = nd
-                    break
-        if not hasattr(node, "names"):
-            return node
-        return None
+        return self.root().default_field()
 
 
 class FTGroup(FTObject):
@@ -727,6 +682,111 @@ class FTGroup(FTObject):
         """
         FTObject._reopen(self)
 
+    def default_field(self, signals=None, nexuspath=None):
+        """ field pointed by default attributes
+
+        :type signals: :obj:`list`<:obj:`str`>
+        :param axes: axes names
+        :param entryname: base nexus path to be opened
+        :type entryname: :obj:`str`
+        :returns: field pointed by default attributes
+        :rtype: :class:`FTField`
+        """
+
+        node = self
+        searching = True
+        nexuspath = nexuspath or ""
+        groups = [n for n in nexuspath.split("/") if n]
+        while searching:
+            nname = None
+            if hasattr(node, "names"):
+                gname = ""
+                if groups:
+                    gname = groups.pop(0)
+                if gname in node.names():
+                    node = node.open(gname)
+                    continue
+                else:
+                    groups = []
+                attrs = node.attributes
+                if "default" in attrs.names():
+                    nname = attrs["default"].read()
+                    if isinstance(nname, numpy.ndarray) and len(nname):
+                        nname = nname[0]
+                    if nname in node.names():
+                        node = node.open(nname)
+                        continue
+            searching = False
+        if not hasattr(node, "names"):
+            return node
+        if hasattr(node, "names"):
+            if groups:
+                gname = groups.pop(0)
+            if gname in node.names():
+                node = node.open(gname)
+                if not hasattr(node, "names"):
+                    return node
+            else:
+                groups = []
+                attrs = node.attributes
+                if "signal" in attrs.names():
+                    nname = attrs["signal"].read()
+                    if isinstance(nname, numpy.ndarray) and len(nname):
+                        nname = nname[0]
+                    if nname in node.names():
+                        node = node.open(nname)
+                    if not hasattr(node, "names"):
+                        return node
+
+        for cnm in ["NXentry", "NXdata", "NXmonitor", "NXlog"]:
+            names = node.names()
+            if cnm[2:] in names:
+                snames = [cnm[2:]]
+            else:
+                snames = []
+            snames.extend(sorted([nm for nm in names if nm != cnm[2:]]))
+            for nn in snames:
+                nd = node.open(nn)
+                if not hasattr(nd, "attributes"):
+                    continue
+                attrs = nd.attributes
+                if "NX_class" in attrs.names():
+                    nname = attrs["NX_class"].read()
+                    if isinstance(nname, numpy.ndarray) and len(nname):
+                        nname = nname[0]
+                    if nname in cnm:
+                        node = nd
+                        break
+        if hasattr(node, "names") and hasattr(node, "attributes"):
+            attrs = node.attributes
+            if "signal" in attrs.names():
+                nname = attrs["signal"].read()
+                if isinstance(nname, numpy.ndarray) and len(nname):
+                    nname = nname[0]
+                if nname in node.names():
+                    node = node.open(nname)
+        if not hasattr(node, "names"):
+            return node
+        while hasattr(node, "names") and "data" in node.names():
+            node = node.open("data")
+        if hasattr(node, "names"):
+            if signals:
+                for signal in signals:
+                    if signal in node.names():
+                        nd = node.open(signal)
+                        if not hasattr(signal, "names"):
+                            node = nd
+                            break
+        if hasattr(node, "names"):
+            for nn in sorted(node.names()):
+                nd = node.open(nn)
+                if not hasattr(nd, "names"):
+                    node = nd
+                    break
+        if not hasattr(node, "names"):
+            return node
+        return None
+
 
 class FTVirtualFieldLayout(FTObject):
 
@@ -932,9 +992,49 @@ class FTDataFilter(FTObject):
         #: (:obj:`int`) compression rate
         self._rate = 0
         #: (:obj:`int`) compression filter id
-        self._filterid = 1
+        self._filterid = 0
         #: (:obj:`tuple` <:obj:`int`>) compression options
         self._options = tuple()
+        #: (:obj:`str`) filter name
+        self._name = ""
+        #: (:obj:`str`) filter availability
+        self._availability = ""
+
+    @property
+    def name(self):
+        """ getter for filter name
+
+        :returns: filter name
+        :rtype: :obj:`tuple` <:obj:`str`>
+        """
+        return self._name
+
+    @name.setter
+    def name(self, value):
+        """ setter for filter name
+
+        :param value: filter name
+        :type value: :obj:`tuple` <:obj:`str`>
+        """
+        self._name = value
+
+    @property
+    def availability(self):
+        """ getter for filter availability
+
+        :returns: filter availability
+        :rtype: :obj:`tuple` <:obj:`str`>
+        """
+        return self._availability
+
+    @availability.setter
+    def availability(self, value):
+        """ setter for filter availability
+
+        :param value: filter availability
+        :type value: :obj:`tuple` <:obj:`str`>
+        """
+        self._availability = value
 
     @property
     def options(self):
@@ -1110,7 +1210,7 @@ class FTAttribute(FTObject):
         """ write attribute value
 
         :param t: slice tuple
-        :type t: :obj:`tuple`
+        :type t: :obj:`tuple` <:obj:`int`>
         :param o: python object
         :type o: :obj:`any`
         """
@@ -1119,7 +1219,7 @@ class FTAttribute(FTObject):
         """ read attribute value
 
         :param t: slice tuple
-        :type t: :obj:`tuple`
+        :type t: :obj:`tuple` <:obj:`int`>
         :returns: python object
         :rtype: :obj:`any`
         """
