@@ -33,6 +33,11 @@ import json
 import re
 import logging
 
+try:
+    from pyqtgraph import QtWidgets
+except Exception:
+    from pyqtgraph import QtGui as QtWidgets
+
 from . import imageField
 from . import imageFileHandler
 
@@ -105,7 +110,7 @@ __all__ = [
 logger = logging.getLogger("lavue")
 
 
-class SourceBaseWidget(QtGui.QWidget):
+class SourceBaseWidget(QtWidgets.QWidget):
 
     """ general source widget """
 
@@ -137,13 +142,13 @@ class SourceBaseWidget(QtGui.QWidget):
         :param parent: parent object
         :type parent: :class:`pyqtgraph.QtCore.QObject`
         """
-        QtGui.QWidget.__init__(self, parent)
+        QtWidgets.QWidget.__init__(self, parent)
 
         #: (:obj:`int`) source id
         self._sourceid = sourceid
         #: (:obj:`list` <:obj:`str`>) subwidget object names
         self.widgetnames = []
-        #: (:obj:`list` <:class:`PyQt5.QtGui.QWidget`>) subwidget objects
+        #: (:obj:`list` <:class:`PyQt5.QtWidgets.QWidget`>) subwidget objects
         self.widgets = []
         #: (:obj:`bool`) source widget active
         self.active = False
@@ -251,12 +256,14 @@ class SourceBaseWidget(QtGui.QWidget):
                 currentattr = str(combobox.currentText()).strip()
                 attrs = sorted(atdict.keys())
                 if currentattr in attrs:
-                    if QtGui.QMessageBox.question(
+                    if QtWidgets.QMessageBox.question(
                             combobox, "Removing Label",
                             'Would you like  to remove "%s"" ?' %
                             (currentattr),
-                            QtGui.QMessageBox.Yes | QtGui.QMessageBox.No,
-                            QtGui.QMessageBox.Yes) == QtGui.QMessageBox.No:
+                            QtWidgets.QMessageBox.Yes
+                            | QtWidgets.QMessageBox.No,
+                            QtWidgets.QMessageBox.Yes) == \
+                                QtWidgets.QMessageBox.No:
                         return False
                     value = str(atdict.pop(currentattr)).strip()
                     if value not in atlist:
@@ -756,6 +763,8 @@ class ASAPOSourceWidget(SourceBaseWidget):
         self.__beamtime = ""
         #: (:obj:`str`>) source path
         self.__sourcepath = ""
+        #: (:obj:`str`>) beamtime metadata file
+        self.__btmetafile = ""
         #: (:obj:`str`>) asapo token
         self.__token = ""
 
@@ -796,10 +805,7 @@ class ASAPOSourceWidget(SourceBaseWidget):
                     currentIndexChanged.disconnect(
                         self._updateStreamComboBox)
             if not self._ui.asapostreamComboBox.count() \
-               or not self._ui.asapodatasourceComboBox.currentText() \
-               or not self.__server \
-               or not self.__token \
-               or not self.__beamtime:
+               or not self._ui.asapodatasourceComboBox.currentText():
                 self.buttonEnabled.emit(False)
             else:
                 self.buttonEnabled.emit(True)
@@ -817,12 +823,13 @@ class ASAPOSourceWidget(SourceBaseWidget):
         :returns configuration: configuration string
         :rtype configuration: :obj:`str`
         """
-        return "%s,%s,%s,%s,%s,%s" % (
+        return "%s,%s,%s,%s,%s,%s,%s" % (
             self.__server,
             str(self._ui.asapodatasourceComboBox.currentText()),
             str(self._ui.asapostreamComboBox.currentText()),
             self.__beamtime,
             self.__sourcepath,
+            self.__btmetafile,
             self.__token
         )
 
@@ -830,6 +837,7 @@ class ASAPOSourceWidget(SourceBaseWidget):
                        asapobeamtime=None,
                        asapodatasources=None, asapostreams=None,
                        asaposourcepath=None,
+                       asapobtmetafile=None,
                        disconnect=True,
                        **kargs):
         """ update source input parameters
@@ -846,6 +854,8 @@ class ASAPOSourceWidget(SourceBaseWidget):
         :type asapostreams: :obj:`list` <:obj:`str`> >
         :param asaposourcepath: source path
         :type asaposourcepath: :obj:`str`
+        :param asapobtmetafile: beamtime metadata file
+        :type asapobtmetafile: :obj:`str`
         :param disconnect: disconnect on update
         :type disconnect: :obj:`bool`
         :param kargs:  source widget input parameter dictionary
@@ -877,6 +887,8 @@ class ASAPOSourceWidget(SourceBaseWidget):
             self.__beamtime = asapobeamtime
         if asaposourcepath is not None:
             self.__sourcepath = asaposourcepath
+        if asapobtmetafile is not None:
+            self.__btmetafile = asapobtmetafile
         updatecombo = False
         if isinstance(asapostreams, list):
             with QtCore.QMutexLocker(self.__mutex):
@@ -1987,7 +1999,7 @@ class NXSFileSourceWidget(SourceBaseWidget):
         if obj not in [self._ui.nxsFileLineEdit, self._ui.nxsFieldLineEdit]:
             return False
         if event.type() in [QtCore.QEvent.MouseButtonDblClick]:
-            fileDialog = QtGui.QFileDialog()
+            fileDialog = QtWidgets.QFileDialog()
             fileout = fileDialog.getOpenFileName(
                 self._ui.nxsFileLineEdit, 'Load file', self.__nxslastfile)
             if isinstance(fileout, tuple):
@@ -2173,6 +2185,8 @@ class ZMQSourceWidget(SourceBaseWidget):
         self.__zmqtopics = []
         #: (:obj:`bool`) automatic zmq topics enabled
         self.__autozmqtopics = False
+        #: (:obj:`bool`)  zmq colon enabled
+        self.__zmqcolon = False
 
         #: (:obj:`dict` <:obj:`str`, :obj:`str`>) dictionary with
         #:                     (label, server:port) items
@@ -2253,7 +2267,11 @@ class ZMQSourceWidget(SourceBaseWidget):
             hosturl = ""
         else:
             try:
-                _, sport = hosturl.split("/")[0].split(":")
+                if not self.__zmqcolon:
+                    _, sport = hosturl.split("/")[0].split(":")
+                else:
+                    _, sport = tuple(hosturl.split(":")[:2])
+
                 port = int(sport)
                 if port > 65535 or port < 0:
                     raise Exception("Wrong port")
@@ -2261,12 +2279,20 @@ class ZMQSourceWidget(SourceBaseWidget):
                     text = self._ui.pickleTopicComboBox.currentText()
                     if text == "**ALL**":
                         text = ""
-                    shost = hosturl.split("/")
-                    if len(shost) > 2:
-                        shost[1] = str(text)
+                    if not self.__zmqcolon:
+                        shost = hosturl.split("/")
+                        if len(shost) > 1:
+                            shost[1] = str(text)
+                        else:
+                            shost.append(str(text))
+                        hosturl = "/".join(shost)
                     else:
-                        shost.append(str(text))
-                    hosturl = "/".join(shost)
+                        shost = hosturl.split(":")
+                        if len(shost) > 2:
+                            shost[2] = str(text)
+                        else:
+                            shost.append(str(text))
+                        hosturl = ":".join(shost)
             except Exception:
                 hosturl = ""
         return hosturl
@@ -2287,6 +2313,7 @@ class ZMQSourceWidget(SourceBaseWidget):
             self,
             zmqtopics=None, autozmqtopics=None,
             datasources=None, disconnect=True, zmqservers=None,
+            zmqcolon=None,
             **kargs):
         """ update source input parameters
 
@@ -2301,6 +2328,8 @@ class ZMQSourceWidget(SourceBaseWidget):
         :param zmqservers: json dictionary with
                            (label, zmq servers) items
         :type zmqservers: :obj:`str`
+        :param zmqcolon: zmq colon configuation separator
+        :type zmqcolon: :obj:`bool`
         :param kargs:  source widget input parameter dictionary
         :type kargs: :obj:`dict` < :obj:`str`, :obj:`any`>
         """
@@ -2324,6 +2353,8 @@ class ZMQSourceWidget(SourceBaseWidget):
             updatecombo = True
         if autozmqtopics is not None:
             self.__autozmqtopics = autozmqtopics
+        if zmqcolon is not None:
+            self.__zmqcolon = zmqcolon
         if self.__autozmqtopics:
             updatecombo = True
             with QtCore.QMutexLocker(self.__mutex):
@@ -2387,13 +2418,24 @@ class ZMQSourceWidget(SourceBaseWidget):
         :param configuration: configuration string
         :type configuration: :obj:`str`
         """
-        cnflst = configuration.replace("/", ",").split(",")
-        srvcnf = cnflst[0] if cnflst else ""
-        topiccnf = ""
-        if len(cnflst) > 1:
-            topiccnf = cnflst[1]
-            if not topiccnf:
-                topiccnf = "**ALL**"
+        if not self.__zmqcolon:
+            cnflst = configuration.replace("/", ",").split(",")
+            srvcnf = cnflst[0] if cnflst else ""
+            topiccnf = ""
+            if len(cnflst) > 1:
+                topiccnf = cnflst[1]
+                if not topiccnf:
+                    topiccnf = "**ALL**"
+        else:
+            cnflst = configuration.replace(":", ",").split(",")
+            topiccnf = ""
+            srvcnf = ""
+            if cnflst and len(cnflst) > 1:
+                srvcnf = "%s:%s" % tuple(cnflst[:2])
+                if len(cnflst) > 2:
+                    topiccnf = cnflst[2]
+                    if not topiccnf:
+                        topiccnf = "**ALL**"
 
         iid = self._ui.pickleComboBox.findText(srvcnf)
         if iid == -1:
@@ -2406,6 +2448,8 @@ class ZMQSourceWidget(SourceBaseWidget):
             if iid == -1:
                 self._ui.pickleTopicComboBox.addItem(topiccnf)
                 iid = self._ui.pickleTopicComboBox.findText(topiccnf)
+            if topiccnf not in self.__zmqtopics:
+                self.__zmqtopics.append(topiccnf)
             self._ui.pickleTopicComboBox.setCurrentIndex(iid)
 
     def label(self):
